@@ -7,17 +7,23 @@ from django.contrib import messages
 from django.contrib.auth import update_session_auth_hash
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.forms import PasswordChangeForm
-from django.core.exceptions import ValidationError
-from django.urls import reverse, reverse_lazy
+from django.core.exceptions import ObjectDoesNotExist
 from django.db import IntegrityError
 from django.http.response import HttpResponseRedirect
 from django.shortcuts import redirect
+from django.urls import reverse, reverse_lazy
 
 import core_main_app.components.data.api as workspace_data_api
-from core_main_app.commons.validators import validate_password
 from core_dashboard_common_app import constants as dashboard_constants
 from core_dashboard_common_app import settings
 from core_dashboard_common_app.views.common.forms import ActionForm, UserForm
+from core_explore_common_app.components.abstract_persistent_query import (
+    api as abstract_persistent_query_api,
+)
+from core_explore_common_app.components.abstract_persistent_query.models import (
+    AbstractPersistentQuery,
+)
+from core_explore_common_app.views.user.views import ResultQueryRedirectView
 from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.components.blob import api as blob_api, utils as blob_utils
 from core_main_app.components.data import api as data_api
@@ -179,43 +185,23 @@ class UserDashboardPasswordChangeFormView(CommonView):
 
     def post(self, request, *args, **kwargs):
         form = PasswordChangeForm(request.user, request.POST)
-
-        try:
-            if form.is_valid():
-                validate_password(request.POST["new_password1"])
-                user = form.save()
-                update_session_auth_hash(request, user)
-                messages.success(request, "Your password was successfully updated!")
-                return redirect(self.success_url)
-            else:
-                messages.error(request, "There are errors on the form.")
-                return render(
-                    request,
-                    self.template_name,
-                    context={"form": form},
-                    assets=self._get_assets(),
-                )
-        except ValidationError as e:
-            error_message = "The following error(s) occurred during validation:"
-            error_items = [str(error) for error in e.messages]
+        if form.is_valid():
+            user = form.save()
+            update_session_auth_hash(request, user)
+            messages.success(request, "Your password was successfully updated!")
+            return redirect(self.success_url)
+        else:
+            messages.error(request, "There are errors on the form.")
             return render(
                 request,
                 self.template_name,
-                context={
-                    "form": form,
-                    "form_error_message": error_message,
-                    "error_items": error_items,
-                },
+                context={"form": form},
                 assets=self._get_assets(),
             )
 
-    def _get_assets(self):
-        return {
-            "css": [
-                "core_dashboard_common_app/common/css/password_form.css",
-                "core_website_app/user/css/list.css",
-            ]
-        }
+    @staticmethod
+    def _get_assets():
+        return {"css": ["core_dashboard_common_app/common/css/password_form.css"]}
 
 
 class DashboardRecords(CommonView):
@@ -398,9 +384,13 @@ class DashboardFiles(CommonView):
 
         detailed_file = []
         for file in files:
+            try:
+                username = user_api.get_user_by_id(file.user_id).username
+            except ObjectDoesNotExist:
+                username = "None"
             detailed_file.append(
                 {
-                    "user": user_api.get_user_by_id(file.user_id).username,
+                    "user": username,
                     "date": file.id.generation_time,
                     "file": file,
                     "url": blob_utils.get_blob_download_uri(file, request),
@@ -661,15 +651,20 @@ class DashboardTemplates(CommonView):
             for template_version in template_versions:
                 # If the version manager doesn't have a user, the template is global.
                 if template_version.user is not None:
+                    try:
+                        username = user_api.get_user_by_id(
+                            template_version.user
+                        ).username
+                    except ObjectDoesNotExist:
+                        username = "None"
+
                     detailed_templates.append(
                         {
                             "template_version": template_version,
                             "template": template_api.get(
                                 template_version.current, request=request
                             ),
-                            "user": user_api.get_user_by_id(
-                                template_version.user
-                            ).username,
+                            "user": username,
                             "title": template_version.title,
                         }
                     )
@@ -746,11 +741,15 @@ class DashboardTypes(CommonView):
             for type_version in type_versions:
                 # If the version manager doesn't have a user, the type is global.
                 if type_version.user is not None:
+                    try:
+                        username = user_api.get_user_by_id(type_version.user).username
+                    except ObjectDoesNotExist:
+                        username = "None"
                     detailed_types.append(
                         {
                             "type_version": type_version,
                             "type": type_api.get(type_version.current, request=request),
-                            "user": user_api.get_user_by_id(type_version.user).username,
+                            "user": username,
                             "title": type_version.title,
                         }
                     )
@@ -832,11 +831,17 @@ class DashboardWorkspaces(CommonView):
 
         detailed_user_workspaces = []
         for user_workspace in user_workspaces:
+            try:
+                username = (
+                    user_api.get_user_by_id(user_workspace.owner).username
+                    if not workspace_api.is_workspace_global(user_workspace)
+                    else "GLOBAL"
+                )
+            except ObjectDoesNotExist:
+                username = "None"
             detailed_user_workspaces.append(
                 {
-                    "user": user_api.get_user_by_id(user_workspace.owner).username
-                    if not workspace_api.is_workspace_global(user_workspace)
-                    else "GLOBAL",
+                    "user": username,
                     "is_owner": self.administration
                     or user_workspace.owner == str(request.user.id),
                     "name": user_workspace.title,
@@ -1062,3 +1067,207 @@ class DashboardWorkspaceRecords(CommonView):
             )
 
         return assets
+
+
+class DashboardQueries(CommonView):
+    """List the queries."""
+
+    template = dashboard_constants.DASHBOARD_TEMPLATE
+
+    def get(self, request, *args, **kwargs):
+        """Method GET
+
+        Args:
+            request:
+            args:
+            kwargs:
+
+        Returns:
+        """
+        # Get all persistent queries
+        persistent_query_subclasses = AbstractPersistentQuery.get_subclasses()
+
+        items_to_render = []
+
+        tab_selected = request.GET.get("tab", persistent_query_subclasses[0].__name__)
+        tabs = []
+
+        for subclass in persistent_query_subclasses:
+            # Get persistent query tabs
+            tabs.append(subclass.__name__)
+
+            # Get selected persistent query tab
+            if tab_selected == subclass.__name__:
+                query_subclass = subclass
+
+        if self.administration:
+            try:
+                items_to_render = (
+                    abstract_persistent_query_api.get_all_persistent_queries(
+                        query_subclass, request.user
+                    )
+                )
+
+            except AccessControlError as ace:
+                abstract_persistent_query_api.get_none(query_subclass)
+        else:
+            items_to_render = (
+                abstract_persistent_query_api.get_all_persistent_queries_by_user(
+                    query_subclass, request.user
+                )
+            )
+
+        # Paginator
+        page = request.GET.get("page", 1)
+        results_paginator = ResultsPaginator.get_results(
+            items_to_render, page, settings.RECORD_PER_PAGE_PAGINATION
+        )
+        for result_view in ResultQueryRedirectView.__subclasses__():
+            if result_view.model_name == query_subclass._class_name:
+                # Get query type
+                url_path = result_view.get_url_path()
+                query_type = result_view.object_name
+                break
+
+        try:
+            detailed_query = self._get_detailed_queries(results_paginator)
+        except:
+            detailed_query = []
+
+        context = {
+            "administration": self.administration,
+            "number_total": items_to_render.count(),
+            "user_data": detailed_query,
+            "document": dashboard_constants.FUNCTIONAL_OBJECT_ENUM.QUERY.value,
+            "template": dashboard_constants.DASHBOARD_QUERIES_TEMPLATE_TABLE,
+            "type": query_type,
+            "url_path": url_path,
+            "tab": tab_selected,
+            "tabs": tabs,
+            "menu": self.administration,
+        }
+
+        if self.administration:
+            context.update(
+                {"action_form": ActionForm([("1", "Delete selected queries")])}
+            )
+
+        modals = [
+            dashboard_constants.MODALS_COMMON_DELETE,
+            "core_main_app/common/modals/error_page_modal.html",
+            "core_explore_common_app/user/persistent_query/modal.html",
+            "core_dashboard_common_app/list/modals/edit_persistent_query.html",
+        ]
+
+        assets = {
+            "css": dashboard_constants.CSS_COMMON,
+            "js": [
+                {
+                    "path": "core_dashboard_common_app/user/js/init.raw.js",
+                    "is_raw": True,
+                },
+                {
+                    "path": "core_main_app/common/js/modals/error_page_modal.js",
+                    "is_raw": True,
+                },
+                {
+                    "path": dashboard_constants.JS_COMMON_FUNCTION_DELETE,
+                    "is_raw": False,
+                },
+                {
+                    "path": dashboard_constants.JS_USER_SELECTED_ELEMENT,
+                    "is_raw": True,
+                },
+                {
+                    "path": "core_main_app/user/js/sharing_modal.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_dashboard_common_app/common/js/persistent_query_config.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_dashboard_common_app/common/js/init_pagination.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_dashboard_app/common/js/my_dashboard_tabs.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_dashboard_common_app/user/js/list/modals/edit_persistent_query.js",
+                    "is_raw": False,
+                },
+            ],
+        }
+        assets["css"].append("core_dashboard_app/common/css/my_dashboard_tabs.css")
+
+        # Admin
+        if self.administration:
+            assets["css"].append("core_dashboard_common_app/admin/css/share_link.css"),
+            assets["js"].append(
+                {
+                    "path": "core_dashboard_common_app/common/js/init_pagination.js",
+                    "is_raw": False,
+                }
+            )
+            assets["js"].append(
+                {"path": dashboard_constants.JS_ADMIN_ACTION_DASHBOARD, "is_raw": True}
+            )
+            assets["js"].append(
+                {"path": dashboard_constants.JS_ADMIN_COUNT_CHECK, "is_raw": True}
+            )
+            assets["js"].append(
+                {"path": dashboard_constants.JS_ADMIN_RESET_CHECKBOX, "is_raw": True}
+            )
+            assets["js"].append(
+                {"path": dashboard_constants.JS_ADMIN_SELECT_ALL, "is_raw": True}
+            )
+            assets["js"].append(
+                {"path": dashboard_constants.JS_ADMIN_SELETED_ELEMENT, "is_raw": False}
+            )
+            assets["js"].append(
+                {"path": dashboard_constants.JS_ADMIN_INIT_MENU, "is_raw": False}
+            )
+            assets["js"].append(
+                {
+                    "path": "core_main_app/user/js/sharing_modal.js",
+                    "is_raw": False,
+                }
+            )
+            assets["js"].append(
+                {
+                    "path": "core_explore_common_app/user/js/persistent_query_config.js",
+                    "is_raw": False,
+                }
+            )
+            assets["js"].append(
+                {
+                    "path": "core_dashboard_common_app/admin/js/my_dashboard_tabs.raw.js",
+                    "is_raw": True,
+                }
+            )
+        else:
+            assets["js"].append(
+                {
+                    "path": "core_dashboard_common_app/user/js/my_dashboard_tabs.raw.js",
+                    "is_raw": True,
+                }
+            )
+
+        return self.common_render(
+            request, self.template, context=context, assets=assets, modals=modals
+        )
+
+    def _get_detailed_queries(self, queries):
+        detailed_queries = []
+        for query in queries:
+            try:
+                user = user_api.get_user_by_id(query.user_id)
+            except ObjectDoesNotExist:
+                user = None
+            except ValueError:
+                user = None
+            detailed_queries.append({"query": query, "user": user})
+
+        return list(reversed(detailed_queries))
